@@ -30,8 +30,10 @@ jsFuncHelper <- function(fxn, params) {
 
   # respect Shiny modules/namespaces
   if (inherits(session , "session_proxy")) {
-    if ("id" %in% names(params)) {
-      params[['id']] <- session$ns(params[['id']])
+    if ("id" %in% names(params) && !is.null(params[['id']])) {
+      if (!"asis" %in% names(params) || !params[['asis']]) {
+        params[['id']] <- session$ns(params[['id']])
+      }
     }
   }
 
